@@ -83,7 +83,7 @@ match_on <- function(x, within = NULL, caliper = NULL, exclude = NULL, data=NULL
 #'   a fitted propensity score model. From this it extracts distances on the
 #'   \emph{linear} propensity score: fitted values of the linear predictor, the
 #'   link function applied to the estimated conditional probabilities, as opposed
-#'   to the estimated conditional probabilities themselves (Rosenbaum \& Rubin,
+#'   to the estimated conditional probabilities themselves (Rosenbaum & Rubin,
 #'   1985).  For example, a logistic model (\code{glm} with
 #'   \code{family=binomial()}) has the logit function as its link, so from such
 #'   models \code{match_on} computes distances in terms of logits of the
@@ -280,6 +280,7 @@ are there missing values in data?")
 #'   \code{"mahalanobis", "euclidean"} or \code{"rank_mahalanobis"}.
 #' @method match_on formula
 #' @rdname match_on-methods
+#' @importFrom stats contrasts
 #' @export
 match_on.formula <- function(x, within = NULL, caliper = NULL, exclude = NULL, data = NULL, subset = NULL, method = "mahalanobis", ...) {
   if (length(x) != 3) {
@@ -338,17 +339,6 @@ match_on.formula <- function(x, within = NULL, caliper = NULL, exclude = NULL, d
     stop("Formula must have a right hand side with at least one variable.")
   }
 
-  # we want to use our own contrasts creating function
-  isF <- colnames(mf)[vapply(mf, is.factor, logical(1))]
-  c.arg <- lapply(isF, function(fname) {
-    if (nlevels(mf[[fname]]) < 2) {
-      return(NULL)
-    }
-    contr.match_on(nlevels(mf[[fname]]))
-  })
-
-  names(c.arg) <- isF
-
   tmpz <- toZ(mf[,1])
   tmpn <- rownames(mf)
 
@@ -362,7 +352,14 @@ match_on.formula <- function(x, within = NULL, caliper = NULL, exclude = NULL, d
   dropped.t <- setdiff(tmpn[tmpz],  rownames(mf))
   dropped.c <- setdiff(tmpn[!tmpz], rownames(mf))
 
-  data <- subset(model.matrix(x, mf, contrasts.arg = c.arg), TRUE, -1) # drop the intercept
+  # Switching contrts function, see #220
+  data <- subset(model.matrix(x, mf,
+                              contrasts.arg =
+                                lapply(Filter(is.factor, mf),
+                                       function(x) {
+                                         stats::contrasts(x, contrasts = FALSE)/sqrt(2)
+                                       })),
+                 TRUE, -1) # drop the intercept
 
   z <- toZ(mf[,1])
   names(z) <- rownames(mf)
@@ -798,20 +795,6 @@ match_on.matrix <- function(x, within = NULL, caliper = NULL, exclude = NULL, da
     return(x + within)
 }
 
-## Non-exported function
-## @title A contrasts function suitable for use within match_on
-## @details Scales the result of `contr.poly` by `2^-1`. Necessary for
-## Euclidean distance to be the same when you apply it with a 2-level
-## factor or with same factor after coercion to numeric.
-## @param n levels of the factor
-## @param contrasts (passed to contr.poly)
-## @param sparse (passed to contr.poly)
-## @return A matrix with `nn=length(n)` rows and `k` columns, with `k=nn-1` if `contrasts` is `TRUE` and `k=nn` if `contrasts` is `FALSE`.
-## @author Ben B Hansen
-contr.match_on <- function(n, contrasts=TRUE, sparse=FALSE) {
-  contr.poly(n, contrasts=contrasts, sparse=sparse)/sqrt(2)
-}
-
 #' pooled dispersion for a numeric variable
 #'
 #' Dispersion as pooled across a treatment and a control group. By default,
